@@ -185,9 +185,10 @@
 #	    	    expmtA<-modelParams$precalcMatrices[[3]]$lexpmtA[[itermNum]]
 #	    	    exptjA<-modelParams$precalcMatrices[[3]]$lexptjA[[itermNum]][vWhichTimes]
 
-		    expmtAcurr<-.calc.exptA(t=-timeDiff,A=modelParams$A) ## correct the mean value structure we are only moving along a single branch
-		    exptAcorr<-expmtAcurr%*%.calc.exptA(t=-phyltree@times[vTermLineage[j-1]],A=modelParams$A)%*%invlexpmtA[[itermNum]]    ## and not through the whole tree, we want the mean at the branch end
-		    exptjA<-sapply(modelParams$precalcMatrices[[3]]$lexptjA[[itermNum]][vWhichTimes],function(mexptjA,exptAcorr){exptAcorr%*%mexptjA},exptAcorr=exptAcorr,simplify=FALSE)
+                    expmtAcurr<-.calc.exptA(t=-timeDiff,modelParams$precalcMatrices[[1]])   ##A=modelParams$A) ## correct the mean value structure we are only moving along a single branch
+##                  exptAcorr<-expmtAcurr%*%.calc.exptA(t=-phyltree@times[vTermLineage[j-1]],A=modelParams$A)%*%invlexpmtA[[itermNum]]    ## and not through the whole tree, we want the mean at the branch end
+##                  exptjA<-sapply(modelParams$precalcMatrices[[3]]$lexptjA[[itermNum]][vWhichTimes],function(mexptjA,exptAcorr){exptAcorr%*%mexptjA},exptAcorr=exptAcorr,simplify=FALSE)
+                    exptjA<-sapply(c(regimes.times[[itermNum]][vWhichTimes]-regimes.times[[itermNum]][vWhichTimes[1]]-timeDiff),function(t,precalc){.calc.exptA(t=t,precalc)},precalc=modelParams$precalcMatrices[[1]],simplify=FALSE)
 		    
 	    	    regimesCurr<-regimes[[itermNum]][vWhichTimes[1:(length(vWhichTimes)-1)]]		
 	    	    names(regimesCurr)<-NULL
